@@ -205,8 +205,9 @@ def render_dot_html(self, node, code, options, prefix='seqdiag',
 
             thumb_size = (options['maxwidth'], image_size[1])
             if not os.path.isfile(toutfn):
+                image.filename = toutfn
                 image.draw()
-                image.save(toutfn, thumb_size)
+                image.save(thumb_size)
 
     except UnicodeEncodeError, e:
         msg = ("seqdiag error: UnicodeEncodeError caught "
